@@ -1,13 +1,32 @@
 # -*- coding: utf-8 -*-
 from __future__ import annotations
 
-from subprocess import CompletedProcess as CompletedProcess
+from subprocess import (
+    DEVNULL as DEVNULL,
+    PIPE as PIPE,
+    CompletedProcess as CompletedProcess,
+    Popen as Popen,
+    run as run,
+)
 
 from xtyping import TypedDict
 
+__subprocess_all__ = (
+    "CompletedProcess",
+    "run",
+    "Popen",
+    "PIPE",
+    "DEVNULL",
+)
 __all__ = (
     "CompletedProcessObj",
     "completed_process_obj",
+    # from subprocess
+    "CompletedProcess",
+    "run",
+    "Popen",
+    "PIPE",
+    "DEVNULL",
 )
 
 
